SystemOrganization addCategory: #ConfigurationOfNeoCSV!

Object subclass: #ConfigurationOfNeoCSV
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfNeoCSV'!

!ConfigurationOfNeoCSV commentStamp: '<historical>' prior: 0!
I am ConfigurationOfNeoCSV, a Metacello configuration for NeoCSV.

NeoCSV is a flexible and efficient reader and writer for CSV and other delimiter-separated-value formats like TSV.

License MIT.!

!ConfigurationOfNeoCSV class methodsFor: 'development support' stamp: 'SvenVanCaekenberghe 6/22/2012 16:27'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfNeoCSV class methodsFor: 'private' stamp: 'SvenVanCaekenberghe 6/22/2012 16:27'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfNeoCSV class methodsFor: 'private' stamp: 'SvenVanCaekenberghe 6/22/2012 16:27'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfNeoCSV class methodsFor: 'private' stamp: 'SvenVanCaekenberghe 6/22/2012 16:27'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfNeoCSV class methodsFor: 'metacello tool support' stamp: 'SvenVanCaekenberghe 6/22/2012 16:27'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfNeoCSV class methodsFor: 'loading' stamp: 'SvenVanCaekenberghe 6/22/2012 16:27'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfNeoCSV class methodsFor: 'loading' stamp: 'SvenVanCaekenberghe 6/22/2012 16:27'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfNeoCSV class methodsFor: 'loading' stamp: 'SvenVanCaekenberghe 6/22/2012 16:27'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfNeoCSV class methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/22/2012 16:27'!
project

	^self new project! !

!ConfigurationOfNeoCSV class methodsFor: 'development support' stamp: 'SvenVanCaekenberghe 6/22/2012 16:27'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfNeoCSV methodsFor: 'baselines' stamp: 'SvenVanCaekenberghe 6/22/2012 16:45'!
baseline1: spec
	<version: '1-baseline'>
	
	spec for: #common do: [
		spec 
			blessing: #baseline;
			repository: 'http://mc.stfx.eu/Neo';
			package: 'Neo-CSV-Core';
			package: 'Neo-CSV-Tests' with: [ spec requires: 'Neo-CSV-Core' ];
			group: 'default' with: #('Neo-CSV-Core' 'Neo-CSV-Tests');
			group: 'Core' with: #('Neo-CSV-Core');
			group: 'Tests' with: #('Neo-CSV-Tests') ]! !

!ConfigurationOfNeoCSV methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/22/2012 16:27'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfNeoCSV methodsFor: 'symbolic versions' stamp: 'SvenVanCaekenberghe 11/4/2012 20:14'!
stable: spec
	<symbolicVersion: #'stable'>
	
	spec for: #common version: '5'! !

!ConfigurationOfNeoCSV methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 9/27/2012 20:31'!
version1: spec
	<version: '1' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'Neo-CSV-Core' with: 'Neo-CSV-Core-SvenVanCaekenberghe.6';
			package: 'Neo-CSV-Tests' with: 'Neo-CSV-Tests-SvenVanCaekenberghe.6' ]! !

!ConfigurationOfNeoCSV methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 9/27/2012 20:31'!
version2: spec
	<version: '2' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'Neo-CSV-Core' with: 'Neo-CSV-Core-SvenVanCaekenberghe.8';
			package: 'Neo-CSV-Tests' with: 'Neo-CSV-Tests-SvenVanCaekenberghe.6' ]! !

!ConfigurationOfNeoCSV methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 9/27/2012 20:31'!
version3: spec
	<version: '3' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'Neo-CSV-Core' with: 'Neo-CSV-Core-SvenVanCaekenberghe.9';
			package: 'Neo-CSV-Tests' with: 'Neo-CSV-Tests-SvenVanCaekenberghe.7' ]! !

!ConfigurationOfNeoCSV methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 9/27/2012 20:40'!
version4: spec
	<version: '4' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'Neo-CSV-Core' with: 'Neo-CSV-Core-SvenVanCaekenberghe.9';
			package: 'Neo-CSV-Tests' with: 'Neo-CSV-Tests-SvenVanCaekenberghe.8' ]! !

!ConfigurationOfNeoCSV methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 11/4/2012 20:14'!
version5: spec
	<version: '5' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'Neo-CSV-Core' with: 'Neo-CSV-Core-SvenVanCaekenberghe.10';
			package: 'Neo-CSV-Tests' with: 'Neo-CSV-Tests-SvenVanCaekenberghe.9' ]! !
